import {
  HELPTOOLTIPS,
  MenderHelpTooltip
} from "./chunk-BRBHG7I6.js";
import {
  docslink_default
} from "./chunk-EUHS2BAH.js";
import {
  MenderTooltipClickable
} from "./chunk-YYRZB2UY.js";
import {
  copy_code_default
} from "./chunk-KTDYMZNU.js";

// src/dialogs/physicaldeviceonboarding.js
import React, { useEffect, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import { Link } from "react-router-dom";
import { InfoOutlined as InfoIcon } from "@mui/icons-material";
import { Autocomplete, TextField, createFilterOptions } from "@mui/material";
import { EXTERNAL_PROVIDER, onboardingSteps } from "@northern.tech/store/constants";
import {
  getCurrentSession,
  getFeatures,
  getFullVersionInformation,
  getIsEnterprise,
  getIsPreview,
  getOnboardingState,
  getOrganization,
  getTenantCapabilities
} from "@northern.tech/store/selectors";
import { advanceOnboarding, setOnboardingApproach, setOnboardingDeviceType } from "@northern.tech/store/thunks";
import { getDebConfigurationCode, versionCompare } from "@northern.tech/utils/helpers";
import { Fragment, jsx, jsxs } from "react/jsx-runtime";
var filter = createFilterOptions();
var types = [
  { title: "Raspberry Pi 3", value: "raspberrypi3" },
  { title: "Raspberry Pi 4", value: "raspberrypi4" }
];
var ConvertedImageNote = () => /* @__PURE__ */ jsxs("p", { children: [
  "We prepared an image, ready for Mender, for you to start with. You can find it in the",
  " ",
  /* @__PURE__ */ jsx(docslink_default, { path: "get-started/preparation/prepare-a-raspberry-pi-device", title: "Prepare a Raspberry Pi device" }),
  " documentation, which also contains instructions for initial device setup. Once you're done flashing you can go ahead and proceed to the next step."
] });
var IntegrationsLink = () => /* @__PURE__ */ jsx(Link, { to: "/settings/integrations", target: "_blank", children: "Integration settings" });
var ExternalProviderTip = ({ hasExternalIntegration, integrationProvider: integrationProvider2 }) => /* @__PURE__ */ jsx(
  MenderTooltipClickable,
  {
    className: "clickable flexbox muted",
    placement: "bottom",
    style: { alignItems: "end", marginBottom: 3 },
    title: /* @__PURE__ */ jsx("div", { style: { maxWidth: 350 }, children: hasExternalIntegration ? /* @__PURE__ */ jsxs("p", { children: [
      "Devices added here will be automatically integrated with the ",
      /* @__PURE__ */ jsx("i", { children: EXTERNAL_PROVIDER[integrationProvider2].title }),
      " you set in the",
      " ",
      /* @__PURE__ */ jsx(IntegrationsLink, {}),
      "."
    ] }) : /* @__PURE__ */ jsxs("p", { children: [
      "To connect your devices with ",
      /* @__PURE__ */ jsx("i", { children: EXTERNAL_PROVIDER[integrationProvider2].title }),
      ", go to ",
      /* @__PURE__ */ jsx(IntegrationsLink, {}),
      " and set up the integration."
    ] }) }),
    children: /* @__PURE__ */ jsx(InfoIcon, {})
  }
);
var DeviceTypeSelectionStep = ({
  hasConvertedImage,
  hasExternalIntegration,
  integrationProvider: integrationProvider2,
  onboardingState,
  onSelect,
  selection = "",
  version
}) => {
  const shouldShowOnboardingTip = !onboardingState.complete && onboardingState.showTips;
  const hasExternalIntegrationSupport = versionCompare(version, "3.2") > -1;
  return /* @__PURE__ */ jsxs(Fragment, { children: [
    /* @__PURE__ */ jsx("h4", { children: "Enter your device type" }),
    /* @__PURE__ */ jsx("p", { children: "Setting this attribute on the device ensures that the device will only receive updates for compatible software releases." }),
    /* @__PURE__ */ jsxs("div", { style: { display: "grid", gridTemplateColumns: "max-content 50px 150px", placeItems: "end center" }, children: [
      /* @__PURE__ */ jsx(
        Autocomplete,
        {
          id: "device-type-selection",
          autoSelect: true,
          autoHighlight: true,
          filterSelectedOptions: true,
          freeSolo: true,
          getOptionLabel: (option) => {
            if (typeof option === "string") {
              return option;
            }
            if (option.key === "custom" && option.value === selection) {
              return option.value;
            }
            return option.title;
          },
          handleHomeEndKeys: true,
          includeInputInList: true,
          filterOptions: (options, params) => {
            const filtered = filter(options, params);
            if (filtered.length !== 1 && params.inputValue !== "") {
              filtered.push({
                value: params.inputValue,
                key: "custom",
                title: `Use "${params.inputValue}"`
              });
            }
            return filtered;
          },
          options: types,
          onChange: onSelect,
          renderInput: (params) => /* @__PURE__ */ jsx(TextField, { ...params, label: "Device type", placeholder: "Choose a device type", InputProps: { ...params.InputProps }, style: { marginTop: 0 } }),
          style: { maxWidth: 300 },
          value: selection
        }
      ),
      hasExternalIntegrationSupport && /* @__PURE__ */ jsx(ExternalProviderTip, { hasExternalIntegration, integrationProvider: integrationProvider2 }),
      shouldShowOnboardingTip ? /* @__PURE__ */ jsx(MenderHelpTooltip, { id: HELPTOOLTIPS.deviceTypeTip.id, placement: "bottom" }) : /* @__PURE__ */ jsx("div", {})
    ] }),
    hasConvertedImage && /* @__PURE__ */ jsx(ConvertedImageNote, {})
  ] });
};
var InstallationStep = ({ advanceOnboarding: advanceOnboarding2, selection, onboardingState, ...remainingProps }) => {
  const codeToCopy = getDebConfigurationCode({ ...remainingProps, deviceType: selection, isOnboarding: !onboardingState.complete });
  return /* @__PURE__ */ jsxs(Fragment, { children: [
    /* @__PURE__ */ jsx("h4", { children: "Log into your device and install the Mender client" }),
    /* @__PURE__ */ jsxs("p", { children: [
      "Copy & paste and run this command ",
      /* @__PURE__ */ jsx("b", { children: "on your device" }),
      ":"
    ] }),
    /* @__PURE__ */ jsx(copy_code_default, { code: codeToCopy, onCopy: () => advanceOnboarding2(onboardingSteps.DASHBOARD_ONBOARDING_START), withDescription: true }),
    /* @__PURE__ */ jsx("p", { children: "This downloads the Mender client on the device, sets the configuration and starts the client." }),
    /* @__PURE__ */ jsx("p", { children: "Once the client has started, your device will attempt to connect to the server. It will then appear in your Pending devices tab and you can continue." })
  ] });
};
var steps = {
  1: DeviceTypeSelectionStep,
  2: InstallationStep
};
var integrationProvider = EXTERNAL_PROVIDER["iot-hub"].provider;
var PhysicalDeviceOnboarding = ({ progress }) => {
  const [selection, setSelection] = useState("");
  const hasExternalIntegration = useSelector((state) => {
    const { credentials = {} } = state.organization.externalDeviceIntegrations.find((integration) => integration.provider === integrationProvider) ?? {};
    const { [EXTERNAL_PROVIDER["iot-hub"].credentialsAttribute]: azureConnectionString = "" } = credentials;
    return !!azureConnectionString;
  });
  const ipAddress = useSelector((state) => state.app.hostAddress);
  const isEnterprise = useSelector(getIsEnterprise);
  const { isDemoMode, isHosted } = useSelector(getFeatures);
  const isPreRelease = useSelector(getIsPreview);
  const onboardingState = useSelector(getOnboardingState);
  const { tenant_token: tenantToken } = useSelector(getOrganization);
  const { Integration: version } = useSelector(getFullVersionInformation);
  const { token } = useSelector(getCurrentSession);
  const { hasMonitor } = useSelector(getTenantCapabilities);
  const dispatch = useDispatch();
  useEffect(() => {
    dispatch(setOnboardingApproach("physical"));
  }, [dispatch]);
  const onSelect = (e, deviceType, reason) => {
    if (reason === "selectOption") {
      dispatch(setOnboardingDeviceType(deviceType.value));
      setSelection(deviceType.value);
    } else if (reason === "clear") {
      dispatch(setOnboardingDeviceType(""));
      setSelection("");
    }
  };
  const hasConvertedImage = !!selection && selection.length && (selection.startsWith("raspberrypi3") || selection.startsWith("raspberrypi4"));
  const ComponentToShow = steps[progress];
  return /* @__PURE__ */ jsx(
    ComponentToShow,
    {
      advanceOnboarding: (step) => dispatch(advanceOnboarding(step)),
      hasConvertedImage,
      hasExternalIntegration,
      hasMonitor,
      integrationProvider,
      ipAddress,
      isEnterprise,
      isHosted,
      isDemoMode,
      isPreRelease,
      onboardingState,
      onSelect,
      selection,
      tenantToken,
      token,
      version
    }
  );
};
var physicaldeviceonboarding_default = PhysicalDeviceOnboarding;

export {
  ConvertedImageNote,
  ExternalProviderTip,
  DeviceTypeSelectionStep,
  InstallationStep,
  PhysicalDeviceOnboarding,
  physicaldeviceonboarding_default
};
//# sourceMappingURL=chunk-GSHMK4U3.js.map